@@ -96,9 +96,9 @@ def parse_args():
                         help="Name of the disease to model "
                              "(default is 'ncov')")
 
-    parser.add_argument('-I', '--input-data', type=str, default="2011Data",
-                        help="Name of the input data set for the network "
-                             "(default is '2011Data')")
+    parser.add_argument('-m', '--model', type=str, default=None,
+                        help="Name of the input model data set for the "
+                             "network (default is '2011Data')")
 
     parser.add_argument('--start-date', type=str, default=None,
                         help="Date of the start of the model outbreak. "
@@ -215,6 +215,12 @@ def parse_args():
                              "exists. Dangerous as this can remove "
                              "existing output files")
 
+    parser.add_argument('--max-nodes', type=int, default=16384,
+                        help="Maximum number of nodes that can be read")
+
+    parser.add_argument('--max-links', type=int, default=4194304,
+                        help="Maximum number of links that can be read")
+
     parser.add_argument('--profile', action="store_true",
                         default=None, help="Enable profiling of the code")
 
@@ -617,7 +623,8 @@ def cli():
     # WE NEED ONE OF these listed options;
     should_run = False
 
-    for arg in [args.input, args.repeats, args.disease, args.additional]:
+    for arg in [args.input, args.repeats, args.disease, args.additional,
+                args.model, args.iterator, args.extractor]:
         if arg is not None:
             should_run = True
             break
@@ -821,7 +828,10 @@ def cli():
     else:
         params.set_disease("ncov")
 
-    params.set_input_files(args.input_data)
+    if args.model:
+        params.set_input_files(args.model)
+    else:
+        params.set_input_files("2011Data")
 
     # load the user-defined custom parameters
     if args.user_variables:
@@ -853,6 +863,8 @@ def cli():
 
     print("\nBuilding the network...")
     network = Network.build(params=params, calculate_distances=True,
+                            max_nodes=args.max_nodes,
+                            max_links=args.max_links,
                             profile=profile)
 
     print("\nRun the model...")
@@ -930,7 +942,7 @@ def cli():
             datestring = ""
 
         RESULTS.write(f"fingerprint,repeat,{varnames}"
-                      f"day,{datestring}S,E,I,R,IW\n")
+                      f"day,{datestring}S,E,I,R,IW,UV\n")
         for varset, trajectory in result:
             varvals = varset.variable_values()
             if varvals is None or len(varvals) == 0:
@@ -949,7 +961,8 @@ def cli():
 
                 RESULTS.write(f"{start}{pop.day},{d}{pop.susceptibles},"
                               f"{pop.latent},{pop.total},"
-                              f"{pop.recovereds},{pop.n_inf_wards}\n")
+                              f"{pop.recovereds},{pop.n_inf_wards},"
+                              f"{pop.scale_uv}\n")
 
     print("End of the run")
 
